@@ -289,6 +289,21 @@ class schemawiz:
 		self.newpostgresconnection()
 		self.newmysqlconnection()
 
+	def justload_postgres_from_csv(self,csvfilename,tablename,withtruncate=False):
+		return_value = ''
+		self.loadcsvfile(csvfilename)
+		delimiter = self.lastcall_delimiter()
+
+		if self.dbthings.postgres_db.does_table_exist(tablename):
+			self.dbthings.postgres_db.load_csv_to_table(csvfilename,tablename,withtruncate,delimiter)
+			rowcount = self.dbthings.postgres_db.queryone('SELECT COUNT(*) FROM ' + tablename)
+			print('Loaded table ' + tablename + ' with ' + str(rowcount) + ' rows.')
+			return_value = tablename
+		else:
+			print('Table ' + tablename + ' does not exist.  Cannot load. \n alternatively try: createload_postgres_from_csv(csvfilename)')
+
+		return return_value
+
 	def createload_postgres_from_csv(self,csvfilename,sztablename=''):
 		return_value = ''
 		self.loadcsvfile(csvfilename)
@@ -312,6 +327,21 @@ class schemawiz:
 
 		return return_value
 
+	def justload_mysql_from_csv(self,csvfilename,tablename,withtruncate=False):
+		return_value = ''
+		self.loadcsvfile(csvfilename)
+		delimiter = self.lastcall_delimiter()
+
+		if self.dbthings.mysql_db.does_table_exist(tablename):
+			self.dbthings.mysql_db.load_csv_to_table(csvfilename,tablename,withtruncate,delimiter)
+			rowcount = self.dbthings.mysql_db.queryone('SELECT COUNT(*) FROM ' + tablename)
+			print('Loaded table ' + tablename + ' with ' + str(rowcount) + ' rows.')
+			return_value = tablename
+		else:
+			print('Table ' + tablename + ' does not exist.  Cannot load. \n alternatively try: createload_mysql_from_csv(csvfilename)')
+
+		return return_value
+
 	def createload_mysql_from_csv(self,csvfilename,sztablename=''):
 		return_value = ''
 		self.loadcsvfile(csvfilename)
